# -*- coding: utf-8 -*-
##############################################################################
#
#    This module is copyright (C) 2013 Numérigraphe SARL. All Rights Reserved.
#
#    This program is free software: you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation, either version 3 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program.  If not, see <http://www.gnu.org/licenses/>.
#
##############################################################################

from openerp.osv import orm
from openerp.tools.translate import _

from stock_inventory_hierarchical import HierarchicalInventoryException

# Add the date to the list of fields we must propagate to children inventories
from stock_inventory_hierarchical import PARENT_VALUES
PARENT_VALUES.append('exhaustive')


class HierarchicalExhInventory(orm.Model):
    """Add hierarchical structure features to exhaustive Inventories"""
    _inherit = 'stock.inventory'

    def action_open(self, cr, uid, ids, context=None):
        """Open only if all the parents are Open."""
        for inventory in self.browse(cr, uid, ids, context=context):
            while inventory.parent_id:
                inventory = inventory.parent_id
                if inventory.state != 'open':
                    raise HierarchicalInventoryException(
                        _('Warning'),
                        _('One of the parent inventories is not open.'))
        return super(HierarchicalExhInventory, self).action_open(
            cr, uid, ids, context=context)

    # TODOv8: probably only keep the state "done"
    def confirm_uninventoried_location_wizard(self, cr, uid, ids,
                                              context=None):
        """Do something only if children state are confirm or done."""
        children_count = self.search(
            cr, uid, [('parent_id', 'child_of', ids),
                      ('id', 'not in', ids),
                      ('state', 'not in', ['confirm', 'done'])],
            context=context, count=True)
        if children_count > 0:
            raise HierarchicalInventoryException(
                _('Warning'),
                _('Some Sub-inventories are not confirmed.'))
        return super(HierarchicalExhInventory,
                     self).confirm_uninventoried_location_wizard(
                         cr, uid, ids, context=context)

    def check_location(self, cr, uid, ids, location_ids, name, context=None):
        """Check if location is a child of parent inventory location"""
        res_location_ids = location_ids[0][2]
        nbr_location_ids = len(res_location_ids)
        loc_obj = self.pool.get('stock.location')
        for inventory in self.browse(cr, uid, ids, context=None):
            if inventory.parent_id.id:
                parent_locations = self.read(
                    cr, uid, [inventory.parent_id.id], ['location_ids'])
                parent_children_locations = loc_obj.search(
                    cr, uid, [('location_id', 'child_of',
                               parent_locations[0]['location_ids'])])
                for location_id in res_location_ids:
                    if location_id not in parent_children_locations:
                        res_location_ids.remove(location_id)
        res = {}
        if nbr_location_ids != len(res_location_ids):
            res['warning'] = {
                'title': _('Warning: Wrong location'),
                'message': _("This location is not declared on the parent "
                             "inventory\n"
                             "It cannot be added.")}
        res['value'] = {'location_ids': res_location_ids}
        return res

    def _fill_location_lines(self, cr, uid, inventory_id, location_ids,
                             set_stock_zero, context=None):
        """Add ids of children inventory into list """
        children_inventory_ids = self.search(
            cr, uid, [('parent_id', 'child_of', inventory_id)])
        context['children_inventory_ids'] = children_inventory_ids
        return super(HierarchicalExhInventory, self)._fill_location_lines(
            cr, uid, inventory_id, location_ids, set_stock_zero,
            context=context)
