# -*- coding: utf-8 -*-
##############################################################################
#
#    This module is copyright (C) 2013 Numérigraphe SARL. All Rights Reserved.
#
#    This program is free software: you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation, either version 3 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program.  If not, see <http://www.gnu.org/licenses/>.
#
##############################################################################

from openerp.osv import orm
from openerp.tools.translate import _

from stock_inventory_hierarchical import HierarchicalInventoryException


class StockInventoryUninventoriedLocation(orm.TransientModel):
    """Consider the lines of the sub-inventories when checking for locations"""
    _inherit = 'stock.inventory.uninventoried.locations'

    def inventories(self, cr, uid, inventory_parent_id):
        """Iterator of children inventories.

        @return: inventory_id
        """
        children_ids = self.pool.get('stock.inventory').search(
            cr, uid, [('parent_id', 'child_of', inventory_parent_id)])
        for inventory_id in children_ids:
            yield inventory_id

    def get_locations(self, cr, uid, inventory_id, context=None):
        """Get all locations through inventory tree."""
        list_inventories_locations_ids = []
        for i_id in self.inventories(cr, uid, inventory_id):
            location_ids = super(
                StockInventoryUninventoriedLocation, self).get_locations(
                cr, uid, i_id, context=context)
            list_inventories_locations_ids = list(set(
                list_inventories_locations_ids + location_ids))
        return list_inventories_locations_ids

    def get_locations_inventoried(self, cr, uid, inventory_id, location_ids,
                                  context=None):
        """Get all locations on inventory lines throughout inventory tree."""
        list_all_inventoried_location_ids = []
        for i_id in self.inventories(cr, uid, inventory_id):
            list_loc_ids = super(
                StockInventoryUninventoriedLocation,
                self).get_locations_inventoried(
                cr, uid, i_id, location_ids, context=context)
            list_all_inventoried_location_ids = list(set(
                list_all_inventoried_location_ids + list_loc_ids))
        return list_all_inventoried_location_ids
