# -*- coding: utf-8 -*-
##############################################################################
#
#    This module is copyright (C) 2013 Numérigraphe SARL. All Rights Reserved.
#
#    This program is free software: you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation, either version 3 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program.  If not, see <http://www.gnu.org/licenses/>.
#
##############################################################################

# TODOv7 refactor to better match the progress in trunk-wms
# - Add locations as many2one instead of one2many
#   http://bazaar.launchpad.net/~openerp-dev/openobject-addons/trunk-wms/revision/9596
# - forbid inventories in the future
#   http://bazaar.launchpad.net/~openerp-dev/openobject-addons/trunk-wms/revision/9598
{
    "name": "Exhaustive Stock Inventories",
    "version": "1.1",
    "depends": ["stock"],
    "author": u"Numérigraphe",
    "category": "Warehouse Management",
    "description": """
Let users make exhaustive Inventories
=====================================

Standard Physical Inventories in OpenERP only contain a generic list of
products by locations, which is well suited to partial Inventories and simple
warehouses. When the a standard Inventory is confirmed, only the products in
the inventory are checked. If a Product is present in the computed stock and
not in the recorded Inventory, OpenERP will consider that it remains unchanged.

But for exhaustive inventories in complex warehouses, it is not practical:
 - you want to avoid Stock Moves to/from these Locations while counting goods
 - you must make sure all the locations you want have been counted
 - you must make sure no other location has been counted by mistake
 - you want the computed stock to perfectly match the inventory when you
   confirm it.

This module lets choose whether an Physical Inventory is exhaustive or
standard. For an exhaustive Inventory, in the state "Draft" you define the list
of Locations where goods must be counted.
 - a new Inventory status ("Open") lets you indicate that the list of Locations
   is definitive and you are now counting the goods.
    In that status, no Stock Moves can be recorded in/out of the Inventory's
    Locations.
 - if some of the Inventory's Locations have not been entered in the Inventory
   Lines, OpenERP warns you when you confirm the Inventory.
 - only the Inventory's Locations can be entered in the Inventory Lines.
 - every good that is not in the Inventory Lines is considered lost, and gets
   moved out of the stock when you confirm the Inventory.
""",
    "data": [
        "wizard/stock_confirm_uninventoried_location.xml",
        "stock_inventory_location_view.xml",
        "wizard/stock_fill_location_inventory_view.xml",
    ],
    "test": [
        "test/inventory_standard_test.yml",
        "test/inventory_exhaustive_test.yml",
        "test/inventory_future_test.yml",
    ],
    "images": [
        # TODOv7 update screenshot
        "images/inventory_form.png",
        # TODOv7 update screenshot
        "inventory_empty_locations.png",
        "images/move_error.png",
    ],
    "demo": ["stock_inventory_location_demo.xml"]
}
